@@ -1,43 +1,16 @@
-#' crul library adapter
-#'
+#' @title CrulAdapter
+#' @description \pkg{crul} library adapter
 #' @export
 #' @family http_lib_adapters
-#' @details
-#' **Methods**
-#'   \describe{
-#'     \item{`enable()`}{
-#'       Enable the adapter
-#'     }
-#'     \item{`disable()`}{
-#'       Disable the adapter
-#'     }
-#'     \item{`build_crul_request(x)`}{
-#'       Build a crul [RequestSignature]
-#'       x: crul request parts (list)
-#'     }
-#'     \item{`build_crul_response(req, resp)`}{
-#'       Build a crul response
-#'       req: a crul request (list)
-#'       resp: a crul response ()
-#'     }
-#'     \item{`handle_request()`}{
-#'       All logic for handling a request
-#'       req: a crul request (list)
-#'     }
-#'     \item{`remove_crul_stubs()`}{
-#'       Remove all crul stubs
-#'     }
-#'   }
-#'
-#' This adapter modifies \pkg{crul} to allow mocking HTTP requests
-#'
-#' @format NULL
-#' @usage NULL
+#' @details This adapter modifies \pkg{crul} to allow mocking HTTP requests
 CrulAdapter <- R6::R6Class(
   'CrulAdapter',
   public = list(
+    #' @field name adapter name
     name = "crul_adapter",
 
+    #' @description Enable the adapter
+    #' @return `TRUE`, invisibly
     enable = function() {
       message("CrulAdapter enabled!")
       webmockr_lightswitch$crul <- TRUE
@@ -45,6 +18,8 @@ CrulAdapter <- R6::R6Class(
       invisible(TRUE)
     },
 
+    #' @description Disable the adapter
+    #' @return `FALSE`, invisibly
     disable = function() {
       message("CrulAdapter disabled!")
       webmockr_lightswitch$crul <- FALSE
@@ -53,6 +28,9 @@ CrulAdapter <- R6::R6Class(
       invisible(FALSE)
     },
 
+    #' @description All logic for handling a request
+    #' @param req a crul request
+    #' @return various outcomes
     handle_request = function(req) {
       # put request in request registry
       request_signature <- build_crul_request(req)
@@ -112,7 +90,13 @@ CrulAdapter <- R6::R6Class(
                 crul_resp$status_code <- toadd[[i]]
               }
               if (names(toadd)[i] == "body") {
-                # crul_resp$content <- toadd[[i]]
+                if (inherits(ss$responses_sequences$body_raw, "mock_file")) {
+                  cat(ss$responses_sequences$body_raw$payload,
+                    file = ss$responses_sequences$body_raw$path,
+                    sep = "\n")
+                  ss$responses_sequences$body_raw <-
+                    ss$responses_sequences$body_raw$path
+                }
                 crul_resp$content <- ss$responses_sequences$body_raw
               }
               if (names(toadd)[i] == "headers") {
@@ -133,6 +117,15 @@ CrulAdapter <- R6::R6Class(
           crul_resp <- vcr::RequestHandlerCrul$new(req)$handle()
         } # vcr is not loaded, skip
 
+        # if written to disk, see if we should modify file path
+        if ("package:vcr" %in% search()) {
+          if (is.character(crul_resp$content)) {
+            write_disk_path <- vcr::vcr_configuration()$write_disk_path
+            write_disk_path <- normalizePath(write_disk_path, mustWork=TRUE)
+            crul_resp$content <- file.path(write_disk_path, basename(crul_resp$content))
+          }
+        }
+
       } else if (webmockr_net_connect_allowed(uri = req$url$url)) {
         # if real requests || localhost || certain exceptions ARE
         #   allowed && nothing found above
@@ -143,6 +136,15 @@ CrulAdapter <- R6::R6Class(
         # if vcr loaded: record http interaction into vcr namespace
         # VCR: recordable
         if ("package:vcr" %in% search()) {
+          # if written to disk, see if we should modify file path
+          if (is.character(crul_resp$content)) {
+            if (file.exists(crul_resp$content)) {
+              write_disk_path <- vcr::vcr_configuration()$write_disk_path
+              write_disk_path <- normalizePath(write_disk_path, mustWork=TRUE)
+              crul_resp$content <- file.path(write_disk_path, basename(crul_resp$content))
+            }
+          }
+
           # stub request so next time we match it
           urip <- crul::url_parse(req$url$url)
           m <- vcr::vcr_configuration()$match_requests_on
@@ -154,7 +156,7 @@ CrulAdapter <- R6::R6Class(
             wi_th(tmp, .list = list(query = urip$parameter))
           } else if (all(m %in% c("method", "uri", "headers")) && length(m) == 3) {
             tmp <- stub_request(req$method, req$url$url)
-            wi_th(tmp, .list = list(query = req$headers))
+            wi_th(tmp, .list = list(headers = req$headers))
           } else if (all(m %in% c("method", "uri", "headers", "query")) && length(m) == 4) {
             tmp <- stub_request(req$method, req$url$url)
             wi_th(tmp, .list = list(query = urip$parameter, headers = req$headers))
@@ -193,6 +195,8 @@ CrulAdapter <- R6::R6Class(
       return(crul_resp)
     },
 
+    #' @description Remove all crul stubs
+    #' @return nothing returned; removes all crul request stubs
     remove_crul_stubs = function() {
       webmockr_stub_registry$remove_all_request_stubs()
     }
@@ -247,7 +251,7 @@ CrulAdapter <- R6::R6Class(
 #' @return a crul response
 build_crul_response <- function(req, resp) {
   # prep headers
-  if (grepl("^ftp://", resp$url)) {
+  if (grepl("^ftp://", resp$url %||% "")) { # in case uri_regex only
     headers <- list()
   } else {
     hds <- resp$headers
@@ -300,7 +304,8 @@ build_crul_request = function(x) {
       body = x$fields %||% NULL,
       headers = x$headers %||% NULL,
       proxies = x$proxies %||% NULL,
-      auth = x$auth %||% NULL
+      auth = x$auth %||% NULL,
+      disk = x$disk %||% NULL
     )
   )
 }
